@@ -72,6 +72,7 @@ class SessionMiddleware:
                         self._cookie_session_id_field
                     )
                     scope["session"] = self.session_backend.get(session_key)
+                    scope["__session_key"] = session_key
 
                 initial_session_was_empty = False
             except (BadTimeSignature, SignatureExpired):
@@ -82,21 +83,18 @@ class SessionMiddleware:
         async def send_wrapper(message: Message, **kwargs) -> None:
             if message["type"] == "http.response.start":
 
-                data = connection.cookies.get(self.cookie_name)
-                data = data.encode("utf-8") if data else None
-
-                session_key = (
-                    json.loads(b64decode(data)).get(self._cookie_session_id_field)
-                    if data
-                    else str(uuid4())
-                )
-
+                session_key = scope.get("__session_key", str(uuid4()))
+                
                 if scope["session"]:
 
                     if self.backend_type == BackendType.cookie:
                         cookie_data = scope["session"]
                     else:
+                        self.session_backend.set(
+                            session_key, scope["session"], self.max_age
+                        )
                         cookie_data = {self._cookie_session_id_field: session_key}
+                        
 
                     data = b64encode(json.dumps(cookie_data).encode("utf-8"))
                     data = self.signer.sign(data)
